@@ -9,10 +9,12 @@ from ctypes.wintypes import DWORD, HWND, ULONG
 from enum import Enum
 from typing import Literal
 
-from tkdev.devicon import Icon_Empty
+from tkdev.devicon import Icon_Empty, Icon_Folder, Icon_Info, Icon_Error, Icon_Warring, Icon_Question, Icon_Questhead, Icon_Hourglass, Icon_QuickFish, Icon_TkinterDev
 from tkdev.devresize import DevResize
 from tkdev.devnet import WindowEffect
 from tkdev.devcore import DevAction, DevSysTray
+from tkdev.devdraw import DrawButton
+from tkdev.devpre import DevPreToolbox, DevPreTooltip
 import warnings
 
 try:
@@ -349,11 +351,12 @@ def window_add_taskbar(window: tk.Tk):
 
 
 def window_border(window: tk.Tk):
-    hWnd = GetParent(window.winfo_id())
-    SetWindowLong(hWnd, GWL_STYLE, GetWindowLong(hWnd, GWL_STYLE) & ~WS_CAPTION)
-    SetWindowPos(hWnd, NULL, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOMOVE | SWP_NOZORDER | SWP_DRAWFRAME)
-    UpdateWindow(hWnd)
-
+    def border():
+        hWnd = GetParent(window.winfo_id())
+        SetWindowLong(hWnd, GWL_STYLE, GetWindowLong(hWnd, GWL_STYLE) & ~WS_CAPTION)
+        SetWindowPos(hWnd, NULL, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOMOVE | SWP_NOZORDER | SWP_DRAWFRAME)
+        UpdateWindow(hWnd)
+    window.after(100, border)
 
 def window_embed(window: tk.Tk, toplevel: tk.Toplevel, iswindow: bool = True):
     def embed():
@@ -1012,27 +1015,6 @@ class DevToplevel(tk.Toplevel, DevWindow):
 
 
 if __name__ == '__main__':
-    from win32gui import (GetParent, SetWindowLong, SetWindowPos, UpdateWindow, ReleaseCapture, SendMessage)
-    from win32con import (GWL_STYLE, WS_CAPTION, NULL, SWP_NOSIZE, SWP_NOMOVE, SWP_NOZORDER, SWP_DRAWFRAME,
-                          WM_SYSCOMMAND, SC_MOVE, HTCAPTION)
-    from tkinter import Tk
-
-    Window = Tk()
-
-
-    def custom():
-        hWnd = GetParent(Window.winfo_id())
-        SetWindowLong(hWnd, GWL_STYLE, GetWindowLong(hWnd, GWL_STYLE) & ~WS_CAPTION)
-        SetWindowPos(hWnd, NULL, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOMOVE | SWP_NOZORDER | SWP_DRAWFRAME)
-        UpdateWindow(hWnd)
-
-
-    def move(evt):
-        ReleaseCapture()
-        SendMessage(GetParent(Window.winfo_id()), WM_SYSCOMMAND,
-                    SC_MOVE + HTCAPTION, 0)
-
-
-    Window.bind("<B1-Motion>", move)
-    Window.after(100, custom)
+    Window = DevWindow()
+    ToolTip = DevPreTooltip(Window, Window)
     Window.mainloop()
\ No newline at end of file
